@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.076'; 
+our $VERSION = '1.078'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -472,7 +472,7 @@ sub info {
 }
 
 sub get_permalink {
-	# This still makes an extra request
+	# This still makes an extra request. Why?
 	my ($self, $commentid, $post_fullname) = @_;
 
 	if (substr ($commentid, 0, 3) eq "t1_") { $commentid = substr $commentid, 3; } 
@@ -707,7 +707,7 @@ sub get_comments { # currently broken
 
 sub submit_comment {
     my ($self, %param) = @_;
-    my $parent_id = $param{parent_id} || croak 'Expected "parent_id"';
+    my $parent_id = $param{parent} || $param{parent_id} || croak 'Expected "parent"';
     my $comment   = $param{text}      || croak 'Expected "text"';
 
     croak '$fullname must be a post or comment' if !$self->ispost($parent_id) && !$self->iscomment($parent_id);
