@@ -39,9 +39,9 @@ sub reply {
 
 sub get_permalink {
 	my $self = shift;
+	my $parentid = substr $self->{parent_id}, 3;
 
-	my $info = $self->{session}->info($self->{link_id});
-	return sprintf "%s%s%s", $self->{session}->LINK_URL, $info->{permalink}, $self->{id};
+	return sprintf "%s/r/$self->{subreddit}/comments/%s//%s", $self->{session}->LINK_URL, $parentid, $self->{id};
 }
 
 1;
